/*
    Language:	English
    Platform:	Win9x/NT/7
    Author:	J. Lipman (info@joellipman.com)
    Website:	www.joellipman.com
    Copyright:	Copyright (C) 2010 Joellipman.Com
    License:	GNU/GPL http://www.gnu.org/copyleft/gpl.html

    Program:	CSV Chart Generator
    Version:	1.0
    Created:	19/05/2010

    Script Function:
	This program is my attempt at graphing events from the Event Viewer
	logs of a Windows 2003 Server instance.  I've decided to use amCharts
	as I have always liked them (www.amcharts.com).  If you want to get
	rid of the amcharts source text, you'll need to pay them for their
	system (not me!).

    License Details:
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


; *************************************************************************************************************
; USUAL SCRIPT STUFF

	#NoEnv
	SendMode Input
	EnvGet, MyTempDir, TEMP
	MyWorkingDir=%MyTempDir%\EventViewerChartsGenerator
	#SingleInstance Force
	SetFormat, float, 0.2


; *************************************************************************************************************
; DECLARE GLOBAL VARIABLES

	ThisProgramName:="CSV Chart Generator"
	ThisProgramVersion:="1.0"


; *************************************************************************************************************
; SETUP MENU BAR

	; Tray Menu
	Menu, Tray, Tip, %ThisProgramName% v%ThisProgramVersion%
	Menu, Tray, NoStandard
	Menu, Tray, Add, Restart, Refresh
	Menu, Tray, Add, Exit, Close

	Gui, Menu


; *************************************************************************************************************
; DRAW GUI - DEFINE OBJECT POSITIONS AND TOOLTIPS

;	Gui, Color, FFFFFF

	; Heading
	Gui, Font, s14 bold c000000
	Gui, Add, Text, x10 w360 vMainHeading, %ThisProgramName%

	; Text
	Gui, Font, s8 normal
	Gui, Add, Text, x20 y50 w360 vIntroText, This program has been created because I want to generate charts based on a CSV export of the Event Logs from a Windows Server 2003 machine.`n`nIt was intended to chart "Security" logs from Windows EventViewer but it has been modified to automatically chart any CSV by grouping its columns.
	Gui, Add, Text, x20 y150 w360 vEventlogLabel, Please select the CSV file to analyze:
	Gui, Add, Text, x20 y215 w100 vChartLabelSystem, Chart System:
	Gui, Add, Text, x205 y215 w100 vChartLabelType, Chart Type:

	Gui, Font, s8 bold c000000

	Gui, Add, Text, x20 y280 w100 vSettingsLabelTitle, Chart Title:
	Gui, Add, Text, x20 y305 w100 vSettingsLabelColumn, Group by:

	Gui, Font, s8 normal c000000
	Gui, Add, Text, x20 y330 w100 vSettingsLabelXAxis, Primary Axis:
	Gui, Add, Text, x20 y355 w100 vSettingsLabelLegend, Show Legend:
	Gui, Add, Text, x205 y280 w100 vSettingsLabelColors, Color Series:
	Gui, Add, Text, x205 y305 w100 vSettingsLabelFile, Settings file:
	Gui, Add, Text, x205 y330 w100 vSettingsLabelGroupOther, Group Other < X:
	Gui, Add, Text, x205 y355 w100 vSettingsLabelLabels, Show Labels:

	; Fields
	Gui, Add, Edit, r1 vEventLogFile x20 y165 w300 h15,
	Gui, Add, Edit, r1 vChartTitle x95 y277 w98 h15, EventViewer Chart
	Gui, Add, Edit, r1 vChartColors x275 y277 w98 h15, #009900,#990000,#0000FF,#FF9900,#CC00CC,#00CCCC,#33FF00,#990000,#000066,#555555
	Gui, Add, Edit, r1 vSettingsFile x275 y302 w78 h15 +ReadOnly,
	Gui, Add, Edit, r1 vGroupOther x275 y327 w98 h15 +ReadOnly, 1`%

	; Dropdowns
	Gui, Add, DropDownList, vChartOutput x20 y230 w175, AM Charts||
	Gui, Add, DropDownList, vChartType x205 y230 w175 gValidateChartType, Area||Bar|Column|Line|Pie
	Gui, Add, DropDownList, vColumnGrouping x95 y302 w98 +AltSubmit,
	Gui, Add, DropDownList, vColumnGroupingX x95 y327 w98 +AltSubmit,
	Gui, Add, DropDownList, vShowLegend x95 y352 w98 +AltSubmit, Yes||No
	Gui, Add, DropDownList, vShowLabels x275 y352 w98 +AltSubmit, Yes||No

	; Buttons
	Gui, Add, Button, x320 y165 w60 h20 vBrowseForCSV gBrowseForCSV +Default +0x8000, Browse...
	Gui, Add, Button, x355 y302 w17 h20 vBrowseForSettings gBrowseForSettings +0x8000, 
	Gui, Font, bold
	Gui, Add, Button, x224 y388 w165 h25 +0x8000 vGenerateChart gGenerateChart, GENERATE CHARTS
	Gui, Font, normal

	; Groupboxes
	Gui, Font, s6
	Gui, Add, GroupBox, x10 y35 w380 h96 vIntroGroupbox, Intro
	Gui, Add, GroupBox, x10 y135 w380 h61 vEventlogGroupbox, Select EventLog FILE
	Gui, Add, GroupBox, x10 y200 w380 h61 vTypeGroupbox, Select CHART Type
	Gui, Add, GroupBox, x10 y265 w380 h116 vSettingsGroupbox, Select SETTINGS

	; Statusbar
	Gui, Font, s8 italic
	Gui, Add, StatusBar,, %A_Space%Ready.

	; Standard stuff
	Gui, Font, s8 normal c000000
	Gui +OwnDialogs +0x800000
	Gui, Show, w400 h440, %ThisProgramName%

	; stop the program
	Return


; *************************************************************************************************************
; FUNCTIONS

ValidateChartType:
	GuiControlGet, ChartType
	If (ChartType="Pie")
	{
		GuiControl, -Readonly, GroupOther
		GuiControl, Disabled, ColumnGroupingX
	} Else {
		GuiControl, +ReadOnly, GroupOther
		GuiControl, Enabled, ColumnGroupingX
	}
;	GuiControl, Disabled, ShowLabels
Return

BrowseForSettings:

	; BROWSE AND SELECT FILE
	FileSelectFile, OutputVar, 1, %EventlogFile%, Please select your AMChart Settings file:, AMChart Settings File (*.xml)
	If (OutputVar<>"")
	{
		MsgBox, 0, Note, Note that by selecting your own settings file, this program`nwill neither overwrite your file nor generate a new one.`n`nSome options in this interface will not apply.  To NOT use`nyour own file, browse and don't open a file (ie. "cancel").
		GuiControl, -ReadOnly, SettingsFile
		GuiControl, +ReadOnly, ChartColors
		GuiControl, Disabled, ShowLegend
		GuiControl, Disabled, ShowLabels
		GuiControl, +ReadOnly, GroupOther
	} else {
		GuiControl, +ReadOnly, SettingsFile
		GuiControl, -ReadOnly, ChartColors
		GuiControl, Enabled, ShowLegend
		GuiControl, Enabled, ShowLabels
		GuiControl, -ReadOnly, GroupOther
	}
	GuiControl,, SettingsFile, %OutputVar%
Return

BrowseForCSV:

	; BROWSE AND SELECT FILE
	FileSelectFile, OutputVar, 1, %EventlogFile%, Please select the CSV exported EventLog file:, Comma Separated Values (*.csv)
	If (OutputVar<>"")
		GuiControl,, EventlogFile, %OutputVar%


	; SCAN FILE FOR COLUMN HEADINGS
	SB_SetText(" Determining headings and possible group_by_column...")
	GuiControlGet, EventLogFile
	EventLogFile=%EventLogFile%
	ColumnHeadings:="", TotalRows:=0
	Loop, Read, %EventLogFile%
	{
		TotalRows++
		If (ColumnHeadings="")
			IfInString, A_LoopReadLine, `,
				ColumnHeadings:=A_LoopReadLine
	}
	CountDataRows:=TotalRows-1
	Grammar:= (CountDataRows=1) ? "" : "s"
	SB_SetText(" " CountDataRows " row" Grammar " ready.")
	If (ColumnHeadings="")
	{
		MsgBox, 16, Error - Not a valid CSV, Ooops! You need to select a CSV (Comma separated value)`nfile that has headings so that I can generate a chart from it.
		Return
	}

	; POPULATE GROUP BY COLUMN HEADINGS
	StringReplace, ColumnHeadings, ColumnHeadings, `,, |, A
	GuiControl,, ColumnGrouping, |%ColumnHeadings%
	GuiControl, Choose, ColumnGrouping, 1

	; POPULATE X-AXIS
	GuiControl,, ColumnGroupingX, |%ColumnHeadings%
	GuiControl, Choose, ColumnGroupingX, 2

	; SUGGEST CHART TITLE
	StringReplace, TempChartTitle, EventLogFile, _, %A_Space%, A
	FilenameWithoutExtension:=SubStr(TempChartTitle, 1, InStr(TempChartTitle, ".", false, 0)-1)
	FilenameWithoutPrefix:=SubStr( FilenameWithoutExtension, InStr( FilenameWithoutExtension, "\", false, 0)+1)
	StringLower, TempChartTitle, FilenameWithoutPrefix, T
	GuiControl,, ChartTitle, %TempChartTitle%



Return

; =============================================================================================================

GenerateChart:
	Gui, Submit, Nohide

	EventLogFile=%EventLogFile%
	If (EventLogFile="")
	{
		MsgBox, 16, Error - No CSV, Ooops! You need to select a CSV file so that I can generate a chart from it.
		Return
	}
	StringReplace, GroupOther, GroupOther, `%, , A
	GroupOther=%GroupOther%
	If (GroupOther="")
		GroupOther:=1

	; -------------------------------------------------------------------------------------------------------------
	; CLEAR CACHED FILES

	IfExist, %A_ScriptDir%\amcharts\amchart.html
		FileDelete, %A_ScriptDir%\amcharts\amchart.html
	IfExist, %A_ScriptDir%\amcharts\amchart_settings.xml
		FileDelete, %A_ScriptDir%\amcharts\amchart_settings.xml
	IfExist, %A_ScriptDir%\amcharts\amchart_data.xml
		FileDelete, %A_ScriptDir%\amcharts\amchart_data.xml

	IfNotExist, %MyWorkingDir%\temp\chart_data
		FileCreateDir, %MyWorkingDir%\temp\chart_data
	IfExist, %MyWorkingDir%\temp\chart_data\chart_data.ini
		FileDelete, %MyWorkingDir%\temp\chart_data\chart_data.ini
	IfNotExist, %MyWorkingDir%\temp\chart_data\chart_data.ini
		FileAppend, [Chart_Data], %MyWorkingDir%\temp\chart_data\chart_data.ini

	; -------------------------------------------------------------------------------------------------------------
	; AREA

	If (ChartType="Area") OR (ChartType="Line") OR (ChartType="Column") OR (ChartType="Bar")
	{
		If (ChartType="Area") OR (ChartType="Line")
			ChartTypeRef:="line"
		Else
			ChartTypeRef:="column"

		NumberOfRows:=0, MyIndex:=0, AlreadyListedSeries:="", AlreadyListedGraphs:="", ThisSeriesRef:=0
		Loop, Read, %EventLogFile%
			NumberOfRows++

		; Usually by date so let's fill out the x-axis
		FileAppend, <?xml version="1.0" encoding="UTF-8"?>`n`n<chart>`n<series>`n, %A_ScriptDir%\amcharts\amchart_data.xml
		Loop, Read, %EventLogFile%
		{
			MyIndex++
			If (MyIndex>1)
			{
				PercentageDone:=(A_Index/NumberOfRows) * 100
				SB_SetText(" Registering Row # " (MyIndex-1) " of " (NumberOfRows-1) " (" PercentageDone "%)")

				StringSplit, OutputArray, A_LoopReadLine, `,
				Unique_Name:=OutputArray%ColumnGrouping%
				Series_Name:=OutputArray%ColumnGroupingX%
				Grouping_Name=%Unique_Name% %Series_Name%
				StringReplace, Grouping_Name, Grouping_Name, %A_Space%, _, A

				; List
				IfNotInstring, AlreadyListedGraphs, %Unique_Name%|
					AlreadyListedGraphs:=AlreadyListedGraphs . Unique_Name .  "|"

				; Populate Series with distinct/unique values
				IniRead, OutputVar, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
				If OutputVar=ERROR
				{
					IniWrite, 1, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
					IfNotInstring, AlreadyListedSeries, %Series_Name%|
					{
						ThisSeriesRef++
						AlreadyListedSeries:=AlreadyListedSeries . Series_Name .  "|"
						TextToAdd:="`t<value xid=""" ThisSeriesRef """>" Series_Name "</value>`n"
						FileAppend, %TextToAdd%, %A_ScriptDir%\amcharts\amchart_data.xml
					}
				} else {
					NewValue:=OutputVar+1
					IniWrite, %NewValue%, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
				}
			}
		}
		FileAppend, </series>`n<graphs>`n, %A_ScriptDir%\amcharts\amchart_data.xml

		StringSplit, AnotherOutputArray, AlreadyListedSeries, |
		StringSplit, YetAnotherOutputArray, AlreadyListedGraphs, |

		MyIndex:=0, OverallIndex:=0, TotalIndex:=YetAnotherOutputArray0 * AnotherOutputArray0

		Loop, %YetAnotherOutputArray0%
		{
			GraphText:="", MySubIndex:=0
			MyIndex++
			GraphText:=YetAnotherOutputArray%MyIndex%
			GraphText=%GraphText%
			If (GraphText="")
				Break

			FileAppend, <graph gid="%MyIndex%">`n, %A_ScriptDir%\amcharts\amchart_data.xml
			Loop, %AnotherOutputArray0%
			{
				OverallIndex++
				PercentageDone:=( OverallIndex / TotalIndex ) * 100
				SB_SetText(" Processing Serie # " OverallIndex " of " TotalIndex " (" PercentageDone "%)")

				SerieText:=""
				MySubIndex++
				SerieText:=AnotherOutputArray%MySubIndex%
				SerieText=%SerieText%
				If (SerieText="")
					Break
				Name_in_config=%GraphText% %SerieText%
				StringReplace, Name_in_config, Name_in_config, %A_Space%, _, A
				IniRead, OutputVar, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Name_in_config%
				ThisValue:=(OutputVar="ERROR") ? 0 : OutputVar
				FileAppend, `t<value xid="%MySubIndex%">%ThisValue%</value>`n, %A_ScriptDir%\amcharts\amchart_data.xml
			}
			FileAppend, </graph>`n, %A_ScriptDir%\amcharts\amchart_data.xml
		}
		FileAppend, </graphs>`n, %A_ScriptDir%\amcharts\amchart_data.xml

		FillArea:=(ChartType="Area") ? "<fill_alpha>50</fill_alpha>" : ""
		UseChartType:=(ChartType="Bar") ? "<type>bar</type>" : ""
		MyIndex:=0

		LegendString:=(ShowLegend=1) ? "<legend><values><enabled>true</enabled><width>80</width><align>left</align><text><![CDATA[: {value}]]></text></values></legend>" : "<legend><values><enabled>false</enabled></values></legend>"
		LabelString:=(ShowLabels=1) ? "<label lid=""0""><x>0</x><y>20</y><align>center</align><text><![CDATA[<b>" ChartTitle "</b>]]></text></label>" : "<label lid=""0""><x>0</x><y>20</y><align>center</align><text><![CDATA[]]></text></label>"

		If SettingsFile=
		{
			FileAppend,
			(
			<?xml version="1.0" encoding="UTF-8"?>
			<settings>
				%UseChartType%
				<decimals_separator>.</decimals_separator>
				<thousands_separator>,</thousands_separator>
				<digits_after_decimal>0</digits_after_decimal>
				<colors>%ChartColors%</colors>
				%LegendString%
				%LabelString%
				<plot_area>
					<margins>
						<left>75</left>
						<top>60</top>
						<right>50</right>
						<bottom>120</bottom>
					</margins>
				</plot_area>
				<graphs>
			),  %A_ScriptDir%\amcharts\amchart_settings.xml
			Loop, %YetAnotherOutputArray0%
			{
				GraphText:="", MySubIndex:=0
				MyIndex++
				GraphText:=YetAnotherOutputArray%MyIndex%
				GraphText=%GraphText%
				If (GraphText="")
					Break
				FileAppend,
				(
				<graph gid="%MyIndex%">
					<axis>left</axis>
					<title>%GraphText%</title>
					%FillArea%
					<balloon_text><![CDATA[{value}]]></balloon_text>
					<data_labels><![CDATA[{value}]]></data_labels>
				</graph>
				),  %A_ScriptDir%\amcharts\amchart_settings.xml
			}
			FileAppend,
			(
				</graphs>
			</settings>
			),  %A_ScriptDir%\amcharts\amchart_settings.xml
		}
	}

	; -------------------------------------------------------------------------------------------------------------
	; PIE

	If (ChartType="Pie")
	{
		ChartTypeRef:="pie"
		NumberOfRows:=0, MyIndex:=0
		Loop, Read, %EventLogFile%
			NumberOfRows++
		Loop, Read, %EventLogFile%
		{
			MyIndex++
			If (MyIndex>1)
			{
				PercentageDone:=(A_Index/NumberOfRows) * 100
				SB_SetText(" Registering Row # " (MyIndex-1) " of " (NumberOfRows-1) " (" PercentageDone "%)")
				StringSplit, OutputArray, A_LoopReadLine, `,
				Grouping_Name:=OutputArray%ColumnGrouping%
				Grouping_Name=%Grouping_Name%

				; Check if this value already exists
				IniRead, OutputVar, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
				If OutputVar=ERROR
				{
					IniWrite, 1, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
				} else {
					NewValue:=OutputVar+1
					IniWrite, %NewValue%, %MyWorkingDir%\temp\chart_data\chart_data.ini, Chart_Data, %Grouping_Name%
				}
			}
		}

		NumberOfGroups:=0, MyIndex:=0
		Loop, Read, %MyWorkingDir%\temp\chart_data\chart_data.ini
			IfInString, A_LoopReadLine, =
				NumberOfGroups++

		FileAppend, <?xml version="1.0" encoding="UTF-8"?>`n<pie>`n, %A_ScriptDir%\amcharts\amchart_data.xml
		Loop, Read, %MyWorkingDir%\temp\chart_data\chart_data.ini
		{
			MyIndex++
			If (MyIndex>1)
			{
				ThisValue:=0

				PercentageDone:=((MyIndex-1) / NumberOfGroups) * 100
				SB_SetText(" Processing Series # " (MyIndex-1) " of " NumberOfGroups " (" PercentageDone "%)")

				ThisGroup:=SubStr( A_LoopReadLine, 1, InStr( A_LoopReadLine, "=", false, 0) - 1 )
				ThisValue:=SubStr( A_LoopReadLine, InStr( A_LoopReadLine, "=", false, 0) + 1 )

				PullOutFirst:=(MyIndex=2) ? " pull_out=""true""" : ""
				TextToAdd:="`t<slice title=""" ThisGroup """" PullOutFirst ">" ThisValue "</slice>`n"
				FileAppend, %TextToAdd%, %A_ScriptDir%\amcharts\amchart_data.xml
			}
		}
		FileAppend, </pie>, %A_ScriptDir%\amcharts\amchart_data.xml

		LegendString:=(ShowLegend=1) ? "<legend><enabled>true</enabled><border_alpha>20</border_alpha><spacing>9</spacing><margins>5</margins><align>center</align><values><text><![CDATA[{value}]]></text></values></legend>" : "<legend><enabled>false</enabled><border_alpha>20</border_alpha><spacing>9</spacing><margins>5</margins><align>center</align><values><text><![CDATA[{value}]]></text></values></legend>"
		LabelString:=(ShowLabels=1) ? "<labels><label lid=""0""><x>0</x><y>10</y><rotate>false</rotate><align>center</align><text_size>12</text_size><text><![CDATA[<b>" ChartTitle "</b>]]></text></label></labels>" : "<labels><enabled>false</enabled><label lid=""0""><x>0</x><y>10</y><rotate>false</rotate><align>center</align><text_size>12</text_size><text><![CDATA[<b></b>]]></text></label></labels>"

		If SettingsFile=
		{
			FileAppend,
			(
			<?xml version="1.0" encoding="UTF-8"?>
			<settings>
				<decimals_separator>.</decimals_separator>
				<thousands_separator>,</thousands_separator>
				<digits_after_decimal>2</digits_after_decimal>
				<pie>
					<radius>90</radius>
					<height>0</height>
					<angle>0</angle>
				</pie>
				<animation>
					<start_time>2</start_time>
					<start_effect>strong</start_effect>
					<sequenced>true</sequenced>
					<pull_out_time>1.5</pull_out_time>
					<pull_out_effect>Bounce</pull_out_effect>
				</animation>
				<data_labels>
					<show><![CDATA[{title}: {percents}`%]]></show>
				</data_labels>
				<group>
					<percent>%GroupOther%</percent>
					<title>_Other (@ less than %GroupOther%`%)</title>
				</group>
				<balloon>
					<alpha>80</alpha>
					<show><![CDATA[]]></show>
				</balloon>
				%LegendString%
				%LabelString%
			</settings>
			),  %A_ScriptDir%\amcharts\amchart_settings.xml
		}
	}

	If SettingsFile<>
		FileCopy, %SettingsFile%, %A_ScriptDir%\amcharts\amchart_settings.xml, 1

	; -------------------------------------------------------------------------------------------------------------
	; GENERATE HTML FILE

	ThisHTMLContent=
	(
		<html>
			<head>
				<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
				<title>%ThisProgramName%</title>
			</head>
			<body>
				<script type="text/javascript" src="am%ChartTypeRef%_swfobject.js"></script>
				<div id="flashcontent">
					<strong>You need to upgrade your Flash Player</strong>
				</div>
				<script type="text/javascript">
					// <![CDATA[
					var so = new SWFObject("am%ChartTypeRef%.swf", "am%ChartTypeRef%", "100`%", "100`%", "8", "#FFFFFF")`;
					so.addVariable("path", "/")`;
					so.addVariable("settings_file", encodeURIComponent("amchart_settings.xml"))`;
					so.addVariable("data_file", encodeURIComponent("amchart_data.xml"))`;
					so.write("flashcontent")`;
					// ]]>
				</script>
			</body>
		</html>
	)

/*
	FileAppend, <html>`n<head>`n<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />`n<title>EventViewer Charts Generator</title>`n</head>`n, %A_ScriptDir%\amcharts\amchart.html
	FileAppend, <body>`n`n<div id="flashcontent"><strong>You need to upgrade your Flash Player</strong></div>`n<script type="text/javascript">`n, %A_ScriptDir%\amcharts\amchart.html
	FileAppend, // <![CDATA[`n, %A_ScriptDir%\amcharts\amchart.html
	LineToAppend=var so = new SWFObject("am%ChartTypeRef%.swf", "am%ChartTypeRef%", "100`%", "100`%", "8", "#FFFFFF")`;`n
	FileAppend, %LineToAppend%, %A_ScriptDir%\amcharts\amchart.html
	LineToAppend=so.addVariable("path", "/")`;`n
	FileAppend, %LineToAppend%, %A_ScriptDir%\amcharts\amchart.html
	LineToAppend=so.addVariable("settings_file", encodeURIComponent("amchart_settings.xml"))`;`n
	FileAppend, %LineToAppend%, %A_ScriptDir%\amcharts\amchart.html
	LineToAppend=so.addVariable("data_file", encodeURIComponent("amchart_data.xml"))`;`n
	FileAppend, %LineToAppend%, %A_ScriptDir%\amcharts\amchart.html
	LineToAppend=so.write("flashcontent")`;`n
	FileAppend, %LineToAppend%, %A_ScriptDir%\amcharts\amchart.html
	FileAppend, // ]]>`n, %A_ScriptDir%\amcharts\amchart.html
	FileAppend, </script></body></html>, %A_ScriptDir%\amcharts\amchart.html
*/
	FileAppend, %ThisHTMLContent%, %A_ScriptDir%\amcharts\amchart.html
	Run %A_ScriptDir%\amcharts\amchart.html

Return


; *************************************************************************************************************
; END PROGRAM

	Refresh:
		Reload
	GuiClose:
	Close:
		Gui, Destroy
		ExitApp
